<?php

/**
 * Class Affilibee_Admin_Menu
 *
 * This class handles the integration of the Affilibee plugin with WooCommerce by adding a custom settings tab in the WooCommerce settings.
 */

class Affilibee_Admin_Menu
{
    /**
     * Initialize the hooks for adding the settings tab and handling its content and updates.
     *
     * Hooks:
     * - Adds a custom settings tab to WooCommerce settings.
     * - Displays the content of the custom settings tab.
     * - Saves the settings when updated.
     * - Adds sections to the custom settings tab.
     * - Displays the content of the Requests section.
     */
    public static function init()
    {
        add_filter('woocommerce_settings_tabs_array', [__CLASS__, 'add_woocommerce_settings_tab'], 50);
        add_action('woocommerce_settings_tabs_affilibee', array(__CLASS__, 'settings_tab_content'));
        add_action('woocommerce_update_options_affilibee', array(__CLASS__, 'update_settings'));
        add_filter('woocommerce_get_sections_affilibee', [__CLASS__, 'add_sections']);
        add_action('woocommerce_settings_affilibee_requests', [__CLASS__, 'settings_tab_requests']);
    }

    /**
     * Add a custom settings tab to the WooCommerce settings.
     *
     * @param array $tabs Existing WooCommerce settings tabs.
     * @return array Modified WooCommerce settings tabs with the Affilibee tab added.
     */
    public static function add_woocommerce_settings_tab($tabs)
    {
        $tabs['affilibee'] = __('Affilibee', 'affilibee');
        return $tabs;
    }

    /**
     * Display the content of the Affilibee settings tab.
     */
    public static function settings_tab_content()
    {
        global $current_section;

        self::render_section_navigation();

        if ($current_section === 'requests') {

            $request_id = isset($_GET['request_id']) ? intval($_GET['request_id']) : 0;

            if ($request_id > 0) {
                Affilibee_Requests_Detail::render($request_id);
            } else {
                Affilibee_Requests_List::render();
            }

        } else {
            Affilibee_Settings::render();
        }
    }

    /**
     * Save the settings when the Affilibee settings tab is updated.
     */
    public static function update_settings()
    {
        Affilibee_Settings::save();
    }

    /**
     * Add sections to the Affilibee settings tab.
     *
     * @param array $sections Existing sections.
     * @return array Modified sections with the Requests section added.
     */
    public static function add_sections($sections)
    {
        $sections[''] = __('Settings', 'affilibee');
        $sections['requests'] = __('Requests', 'affilibee');
        return $sections;
    }

    /**
     * Render the section navigation menu.
     */
    private static function render_section_navigation()
    {
        $sections = apply_filters('woocommerce_get_sections_affilibee', array());
        if (empty($sections)) {
            return;
        }

        global $current_section;
        echo '<ul class="subsubsub">';
        $array_keys = array_keys($sections);
        foreach ($sections as $id => $label) {
            echo '<li>';
            $url = admin_url('admin.php?page=wc-settings&tab=affilibee&section=' . sanitize_title($id));
            $class = ($current_section == $id ? 'current' : '');
            echo '<a href="' . esc_url($url) . '" class="' . esc_attr($class) . '">' . esc_html($label) . '</a>';
            if (end($array_keys) !== $id) {
                echo ' | ';
            }
            echo '</li>';
        }
        echo '</ul><br class="clear" />';
    }
}