<?php

/**
 * Class Affilibee_Activator
 *
 * This class handles the activation process for the Affilibee plugin.
 *
 * @package Affilibee
 */
class Affilibee_Activator {
    public static function activate() {
        self::check_environment();
        Affilibee_Database::create_tables();
        self::register_admin_notices();
    }

    /**
     * Check if the current environment meets the minimum requirements.
     *
     * This function performs the following checks:
     * 1. Ensures the 'is_plugin_active' function is available.
     * 2. Verifies the PHP version meets the minimum requirement defined in Affilibee_Config::MINIMUM_PHP_VERSION.
     * 3. Verifies the WordPress version meets the minimum requirement defined in Affilibee_Config::MINIMUM_WP_VERSION.
     * 4. Checks if WooCommerce is installed and activated.
     * 5. Verifies the WooCommerce version meets the minimum requirement defined in Affilibee_Config::MINIMUM_WC_VERSION.
     *
     * If any of the checks fail, appropriate messages are set and the plugin may be deactivated or admin notices may be displayed.
     */
    private static function check_environment() {
        if (!function_exists('is_plugin_active')) {
            include_once ABSPATH . 'wp-admin/includes/plugin.php';
        }

        if (version_compare(PHP_VERSION, Affilibee_Config::MINIMUM_PHP_VERSION, '<')) {
            $current_php = PHP_VERSION;
            $min_php = Affilibee_Config::MINIMUM_PHP_VERSION;
            $message = sprintf(
                __('Affilibee has been deactivated because it requires PHP version %s or higher. Your current PHP version is %s.', 'affilibee'),
                $min_php,
                $current_php
            );
            self::deactivate_plugin($message);
            return;
        }

        global $wp_version;
        if (version_compare($wp_version, Affilibee_Config::MINIMUM_WP_VERSION, '<')) {
            $current_wp = $wp_version;
            $min_wp = Affilibee_Config::MINIMUM_WP_VERSION;
            $message = sprintf(
                __('Affilibee requires WordPress version %s or higher. Your current WordPress version is %s.', 'affilibee'),
                $min_wp,
                $current_wp
            );
            self::set_admin_notice($message);
        }

        if (!is_plugin_active('woocommerce/woocommerce.php')) {
            $message = __('Affilibee requires WooCommerce to be installed and activated.', 'affilibee');
            self::set_admin_notice($message);
        }

        if (defined('WC_VERSION')) {
            $wc_version = WC_VERSION;
            if (version_compare($wc_version, Affilibee_Config::MINIMUM_WC_VERSION, '<')) {
                $message = sprintf(
                    __('Affilibee requires WooCommerce version %s or higher. Your current WooCommerce version is %s.', 'affilibee'),
                    Affilibee_Config::MINIMUM_WC_VERSION,
                    $wc_version
                );
                self::set_admin_notice($message);
            }
        } else {
            $message = __('Affilibee requires WooCommerce to be installed and activated.', 'affilibee');
            self::set_admin_notice($message);
        }
    }

    /**
     * Deactivate the plugin and set an error transient to display as an admin notice.
     *
     * @param string $message The message to display to the user.
     */
    private static function deactivate_plugin($message) {
        deactivate_plugins(plugin_basename(AFFILIBEE_PLUGIN_FILE));
        set_transient('affilibee_deactivation_error', $message, 5);
    }

    /**
     * Set an admin notice transient to display a message without deactivating the plugin.
     *
     * @param string $message The message to display to the user.
     */
    private static function set_admin_notice($message) {
        set_transient('affilibee_admin_notice', $message, 5);
    }

    /**
     * Register the admin notice for activation errors.
     */
    private static function register_admin_notices() {
        add_action('admin_notices', array(__CLASS__, 'affilibee_activation_error_notice'));
        add_action('admin_notices', array(__CLASS__, 'affilibee_general_admin_notice'));
    }

    /**
     * Display the activation error notice in the admin dashboard.
     */
    public static function affilibee_activation_error_notice() {
        if ($error_message = get_transient('affilibee_deactivation_error')) {
            ?>
            <div class="notice notice-error is-dismissible">
                <p><?php echo esc_html($error_message); ?></p>
            </div>
            <?php
            delete_transient('affilibee_deactivation_error');
        }
    }

    /**
     * Display general admin notices in the admin dashboard.
     */
    public static function affilibee_general_admin_notice() {
        if ($notice_message = get_transient('affilibee_admin_notice')) {
            ?>
            <div class="notice notice-error">
                <p><?php echo esc_html($notice_message); ?></p>
            </div>
            <?php
            delete_transient('affilibee_admin_notice');
        }
    }
}